/**
 * vue-markdown-wasm
 *
 * @description markdown-wasm for vue 2 & 3
 * @author Logue <logue@hotmail.co.jp>
 * @copyright 2022-2023 By Masashi Yoshikawa All rights reserved.
 * @license MIT
 * @version 0.3.10
 * @see {@link https://github.com/logue/vue-markdown-wasm}
 */

var VueMarkdown = (function (exports, vueDemi, markdownWasm) {
  'use strict';

  const adaptOnsV3 = (ons) => {
    if (!ons)
      return {};
    return Object.entries(ons).reduce((ret, [key, handler]) => {
      key = key.charAt(0).toUpperCase() + key.slice(1);
      key = `on${key}`;
      return { ...ret, [key]: handler };
    }, {});
  };
  function h(type, options = {}, chidren) {
    if (vueDemi.isVue2) {
      return vueDemi.h(type, options, chidren);
    }
    const { props, domProps, on, ...extraOptions } = options;
    const ons = on != null ? adaptOnsV3(on) : {};
    return vueDemi.h(
      type,
      { ...extraOptions, ...props, ...domProps, ...ons },
      chidren
    );
  }

  var VueMarkdown = vueDemi.defineComponent({
    /** Component Name */
    name: "VueMarkdown",
    /** Model Definition */
    model: {
      prop: "modelValue"
    },
    /** Props Definition */
    props: {
      /** Model value */
      modelValue: {
        type: String,
        default: ""
      },
      /**
       * Using tag
       */
      tag: {
        type: String,
        default: "article"
      },
      /** Customize parsing */
      parseFlags: {
        type: Number,
        default: markdownWasm.ParseFlags.DEFAULT
      },
      /** Select output format. */
      format: {
        type: String,
        default: "xhtml"
      },
      /**
       * bytes=true causes parse() to return the result as a Uint8Array instead of a string.
       *
       * The returned Uint8Array is only valid until the next call to parse().
       * If you need to keep the returned data around, call Uint8Array.slice() to make a copy,
       * as each call to parse() uses the same underlying memory.
       *
       * This only provides a performance benefit when you never need to convert the output
       * to a string. In most cases you're better off leaving this unset or false.
       */
      bytes: {
        type: Boolean,
        default: false
      },
      /** Allow "javascript:" in links */
      allowJsUri: {
        type: Boolean,
        default: false
      },
      /**
       * Optional callback which if provided is called for each code block.
       * langname holds the "language tag", if any, of the block.
       *
       * The returned value is inserted into the resulting HTML verbatim, without HTML escaping.
       * Thus, you should take care of properly escaping any special HTML characters.
       *
       * If the function returns null or undefined, or an exception occurs, the body will be
       * included as-is after going through HTML escaping.
       *
       * Note that use of this callback has an adverse impact on performance as it casues
       * calls and data to be bridged between WASM and JS on every invocation.
       */
      onCodeBlock: {
        type: Function,
        default: () => {
          return void 0;
        }
      }
    },
    /** Emits */
    emits: {
      render: (value) => true
    },
    /**
     * Setup
     *
     * @param props  - Props
     * @param context - Context
     */
    setup(props, context) {
      const placeholder = vueDemi.ref();
      const html = vueDemi.ref("");
      vueDemi.watch(
        () => props,
        async (value) => {
          html.value = render(value.modelValue, {
            parseFlags: value.parseFlags,
            format: value.format,
            bytes: props.bytes,
            allowJSURIs: value.allowJsUri,
            onCodeBlock: value.onCodeBlock
          });
          await vueDemi.nextTick();
        },
        { deep: true }
      );
      vueDemi.onMounted(async () => {
        await markdownWasm.ready();
        html.value = render(props.modelValue, {
          parseFlags: props.parseFlags,
          format: props.format,
          bytes: props.bytes,
          allowJSURIs: props.allowJsUri,
          onCodeBlock: props.onCodeBlock
        });
      });
      const render = (source, options) => {
        const ret = markdownWasm.parse(source, options);
        context.emit("render", ret);
        return ret;
      };
      context.expose({
        render
      });
      return {
        placeholder,
        html
      };
    },
    render() {
      return h(this.$props.tag, {
        ref: "placeholder",
        class: "vue-markdown",
        domProps: {
          innerHTML: this.html
        }
      });
    }
  });

  const meta = {
    version: "0.3.10",
    date: "2023-08-11T00:54:40.896Z"
  };

  const installVueMarkdown = (app) => app.component("VueMarkdown", VueMarkdown);
  if (typeof window !== "undefined" && window.Vue) {
    window.Vue.use(installVueMarkdown);
  }

  exports.Meta = meta;
  exports["default"] = VueMarkdown;
  exports.install = installVueMarkdown;

  Object.defineProperty(exports, '__esModule', { value: true });

  return exports;

})({}, VueDemi, markdown);
